# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.simulations_api import SimulationsApi  # noqa: E501
from proton_api.rest import ApiException


class TestSimulationsApi(unittest.TestCase):
    """SimulationsApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.simulations_api.SimulationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_backtest(self):
        """Test case for backtest

        Backtest  # noqa: E501
        """
        pass

    def test_event_study(self):
        """Test case for event_study

        Event Study  # noqa: E501
        """
        pass

    def test_monte_carlo(self):
        """Test case for monte_carlo

        Monte Carlo  # noqa: E501
        """
        pass

    def test_portfolio_what_if(self):
        """Test case for portfolio_what_if

        Porfolio What-If  # noqa: E501
        """
        pass

    def test_savings_calculator(self):
        """Test case for savings_calculator

        Savings Calculator  # noqa: E501
        """
        pass

    def test_scenario_analysis(self):
        """Test case for scenario_analysis

        Scenario Analysis  # noqa: E501
        """
        pass

    def test_sensitivity_analysis(self):
        """Test case for sensitivity_analysis

        Sensitivity Analysis  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
