# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.models.education_calculator_deposit_amount_request import EducationCalculatorDepositAmountRequest  # noqa: E501
from proton_api.rest import ApiException


class TestEducationCalculatorDepositAmountRequest(unittest.TestCase):
    """EducationCalculatorDepositAmountRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEducationCalculatorDepositAmountRequest(self):
        """Test EducationCalculatorDepositAmountRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = proton_api.models.education_calculator_deposit_amount_request.EducationCalculatorDepositAmountRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
