# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import proton_api
from proton_api.api.financial_planning_api import FinancialPlanningApi  # noqa: E501
from proton_api.rest import ApiException


class TestFinancialPlanningApi(unittest.TestCase):
    """FinancialPlanningApi unit test stubs"""

    def setUp(self):
        self.api = proton_api.api.financial_planning_api.FinancialPlanningApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_education_calculator_annual_cost(self):
        """Test case for education_calculator_annual_cost

        Education Calculator - Annual Cost  # noqa: E501
        """
        pass

    def test_education_calculator_deposit_amount(self):
        """Test case for education_calculator_deposit_amount

        Education Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_education_calculator_percent_covered(self):
        """Test case for education_calculator_percent_covered

        Education Calculator - Percent Covered  # noqa: E501
        """
        pass

    def test_mortgage_calculator_down_payment(self):
        """Test case for mortgage_calculator_down_payment

        Mortgage Calculator - Down Payment  # noqa: E501
        """
        pass

    def test_mortgage_calculator_home_price(self):
        """Test case for mortgage_calculator_home_price

        Mortgage Calculator - Home Price  # noqa: E501
        """
        pass

    def test_mortgage_calculator_periodic_payment(self):
        """Test case for mortgage_calculator_periodic_payment

        Mortgage Calculator - Periodic Payment  # noqa: E501
        """
        pass

    def test_purchase_calculator_amount(self):
        """Test case for purchase_calculator_amount

        Purchase Calculator - Amount  # noqa: E501
        """
        pass

    def test_purchase_calculator_deposit_amount(self):
        """Test case for purchase_calculator_deposit_amount

        Purchase Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_purchase_calculator_horizon(self):
        """Test case for purchase_calculator_horizon

        Purchase Calculator - Horizon  # noqa: E501
        """
        pass

    def test_retirement_calculator_deposit_amount(self):
        """Test case for retirement_calculator_deposit_amount

        Retirement Calculator - Deposit Amount  # noqa: E501
        """
        pass

    def test_retirement_calculator_expenses(self):
        """Test case for retirement_calculator_expenses

        Retirement Calculator - Expenses  # noqa: E501
        """
        pass

    def test_retirement_calculator_percent_covered(self):
        """Test case for retirement_calculator_percent_covered

        Retirement Calculator - Percent Covered  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
