# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EducationCalculatorPercentCoveredRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aggregation_account_ids': 'list[str]',
        'total_annual_cost': 'float',
        'tax_rate': 'float',
        'account_ids': 'list[str]',
        'initial_balance': 'float',
        'decumulation_horizon': 'int',
        'accumulation_horizon': 'int',
        'education_inflation_rate': 'float',
        'portfolio_return': 'float',
        'deposit_schedule': 'CalculatorDepositSchedule1',
        'general_inflation_rate': 'float'
    }

    attribute_map = {
        'aggregation_account_ids': 'aggregation_account_ids',
        'total_annual_cost': 'total_annual_cost',
        'tax_rate': 'tax_rate',
        'account_ids': 'account_ids',
        'initial_balance': 'initial_balance',
        'decumulation_horizon': 'decumulation_horizon',
        'accumulation_horizon': 'accumulation_horizon',
        'education_inflation_rate': 'education_inflation_rate',
        'portfolio_return': 'portfolio_return',
        'deposit_schedule': 'deposit_schedule',
        'general_inflation_rate': 'general_inflation_rate'
    }

    def __init__(self, aggregation_account_ids=None, total_annual_cost=None, tax_rate=0.0, account_ids=None, initial_balance=0.0, decumulation_horizon=None, accumulation_horizon=None, education_inflation_rate=0.05, portfolio_return=None, deposit_schedule=None, general_inflation_rate=0.0):  # noqa: E501
        """EducationCalculatorPercentCoveredRequest - a model defined in Swagger"""  # noqa: E501

        self._aggregation_account_ids = None
        self._total_annual_cost = None
        self._tax_rate = None
        self._account_ids = None
        self._initial_balance = None
        self._decumulation_horizon = None
        self._accumulation_horizon = None
        self._education_inflation_rate = None
        self._portfolio_return = None
        self._deposit_schedule = None
        self._general_inflation_rate = None
        self.discriminator = None

        if aggregation_account_ids is not None:
            self.aggregation_account_ids = aggregation_account_ids
        self.total_annual_cost = total_annual_cost
        if tax_rate is not None:
            self.tax_rate = tax_rate
        if account_ids is not None:
            self.account_ids = account_ids
        if initial_balance is not None:
            self.initial_balance = initial_balance
        self.decumulation_horizon = decumulation_horizon
        self.accumulation_horizon = accumulation_horizon
        if education_inflation_rate is not None:
            self.education_inflation_rate = education_inflation_rate
        self.portfolio_return = portfolio_return
        if deposit_schedule is not None:
            self.deposit_schedule = deposit_schedule
        if general_inflation_rate is not None:
            self.general_inflation_rate = general_inflation_rate

    @property
    def aggregation_account_ids(self):
        """Gets the aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregation_account_ids

    @aggregation_account_ids.setter
    def aggregation_account_ids(self, aggregation_account_ids):
        """Sets the aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.


        :param aggregation_account_ids: The aggregation_account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: list[str]
        """

        self._aggregation_account_ids = aggregation_account_ids

    @property
    def total_annual_cost(self):
        """Gets the total_annual_cost of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The total_annual_cost of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._total_annual_cost

    @total_annual_cost.setter
    def total_annual_cost(self, total_annual_cost):
        """Sets the total_annual_cost of this EducationCalculatorPercentCoveredRequest.


        :param total_annual_cost: The total_annual_cost of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if total_annual_cost is None:
            raise ValueError("Invalid value for `total_annual_cost`, must not be `None`")  # noqa: E501
        if total_annual_cost is not None and total_annual_cost < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_annual_cost`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_annual_cost = total_annual_cost

    @property
    def tax_rate(self):
        """Gets the tax_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The tax_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, tax_rate):
        """Sets the tax_rate of this EducationCalculatorPercentCoveredRequest.


        :param tax_rate: The tax_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if tax_rate is not None and tax_rate > 1:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value less than or equal to `1`")  # noqa: E501
        if tax_rate is not None and tax_rate < 0:  # noqa: E501
            raise ValueError("Invalid value for `tax_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._tax_rate = tax_rate

    @property
    def account_ids(self):
        """Gets the account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this EducationCalculatorPercentCoveredRequest.


        :param account_ids: The account_ids of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: list[str]
        """

        self._account_ids = account_ids

    @property
    def initial_balance(self):
        """Gets the initial_balance of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The initial_balance of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._initial_balance

    @initial_balance.setter
    def initial_balance(self, initial_balance):
        """Sets the initial_balance of this EducationCalculatorPercentCoveredRequest.


        :param initial_balance: The initial_balance of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if initial_balance is not None and initial_balance < 0:  # noqa: E501
            raise ValueError("Invalid value for `initial_balance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._initial_balance = initial_balance

    @property
    def decumulation_horizon(self):
        """Gets the decumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The decumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._decumulation_horizon

    @decumulation_horizon.setter
    def decumulation_horizon(self, decumulation_horizon):
        """Sets the decumulation_horizon of this EducationCalculatorPercentCoveredRequest.


        :param decumulation_horizon: The decumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if decumulation_horizon is None:
            raise ValueError("Invalid value for `decumulation_horizon`, must not be `None`")  # noqa: E501
        if decumulation_horizon is not None and decumulation_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `decumulation_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._decumulation_horizon = decumulation_horizon

    @property
    def accumulation_horizon(self):
        """Gets the accumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The accumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: int
        """
        return self._accumulation_horizon

    @accumulation_horizon.setter
    def accumulation_horizon(self, accumulation_horizon):
        """Sets the accumulation_horizon of this EducationCalculatorPercentCoveredRequest.


        :param accumulation_horizon: The accumulation_horizon of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: int
        """
        if accumulation_horizon is None:
            raise ValueError("Invalid value for `accumulation_horizon`, must not be `None`")  # noqa: E501
        if accumulation_horizon is not None and accumulation_horizon < 0:  # noqa: E501
            raise ValueError("Invalid value for `accumulation_horizon`, must be a value greater than or equal to `0`")  # noqa: E501

        self._accumulation_horizon = accumulation_horizon

    @property
    def education_inflation_rate(self):
        """Gets the education_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The education_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._education_inflation_rate

    @education_inflation_rate.setter
    def education_inflation_rate(self, education_inflation_rate):
        """Sets the education_inflation_rate of this EducationCalculatorPercentCoveredRequest.


        :param education_inflation_rate: The education_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if education_inflation_rate is not None and education_inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `education_inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._education_inflation_rate = education_inflation_rate

    @property
    def portfolio_return(self):
        """Gets the portfolio_return of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The portfolio_return of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._portfolio_return

    @portfolio_return.setter
    def portfolio_return(self, portfolio_return):
        """Sets the portfolio_return of this EducationCalculatorPercentCoveredRequest.


        :param portfolio_return: The portfolio_return of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if portfolio_return is None:
            raise ValueError("Invalid value for `portfolio_return`, must not be `None`")  # noqa: E501
        if portfolio_return is not None and portfolio_return < -1:  # noqa: E501
            raise ValueError("Invalid value for `portfolio_return`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._portfolio_return = portfolio_return

    @property
    def deposit_schedule(self):
        """Gets the deposit_schedule of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The deposit_schedule of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: CalculatorDepositSchedule1
        """
        return self._deposit_schedule

    @deposit_schedule.setter
    def deposit_schedule(self, deposit_schedule):
        """Sets the deposit_schedule of this EducationCalculatorPercentCoveredRequest.


        :param deposit_schedule: The deposit_schedule of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: CalculatorDepositSchedule1
        """

        self._deposit_schedule = deposit_schedule

    @property
    def general_inflation_rate(self):
        """Gets the general_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501


        :return: The general_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :rtype: float
        """
        return self._general_inflation_rate

    @general_inflation_rate.setter
    def general_inflation_rate(self, general_inflation_rate):
        """Sets the general_inflation_rate of this EducationCalculatorPercentCoveredRequest.


        :param general_inflation_rate: The general_inflation_rate of this EducationCalculatorPercentCoveredRequest.  # noqa: E501
        :type: float
        """
        if general_inflation_rate is not None and general_inflation_rate < -1:  # noqa: E501
            raise ValueError("Invalid value for `general_inflation_rate`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._general_inflation_rate = general_inflation_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EducationCalculatorPercentCoveredRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EducationCalculatorPercentCoveredRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
