# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FinancialPictureRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_date': 'date',
        'client_id': 'str',
        'create_log': 'bool',
        'currency_conversion': 'str',
        'show_history': 'bool',
        'start_date': 'date',
        'currency_code': 'str',
        'show_category_breakdown': 'bool',
        'show_change': 'bool'
    }

    attribute_map = {
        'end_date': 'end_date',
        'client_id': 'client_id',
        'create_log': 'create_log',
        'currency_conversion': 'currency_conversion',
        'show_history': 'show_history',
        'start_date': 'start_date',
        'currency_code': 'currency_code',
        'show_category_breakdown': 'show_category_breakdown',
        'show_change': 'show_change'
    }

    def __init__(self, end_date=None, client_id=None, create_log=False, currency_conversion=None, show_history=False, start_date=None, currency_code=None, show_category_breakdown=True, show_change=False):  # noqa: E501
        """FinancialPictureRequest - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._client_id = None
        self._create_log = None
        self._currency_conversion = None
        self._show_history = None
        self._start_date = None
        self._currency_code = None
        self._show_category_breakdown = None
        self._show_change = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        self.client_id = client_id
        if create_log is not None:
            self.create_log = create_log
        if currency_conversion is not None:
            self.currency_conversion = currency_conversion
        if show_history is not None:
            self.show_history = show_history
        if start_date is not None:
            self.start_date = start_date
        if currency_code is not None:
            self.currency_code = currency_code
        if show_category_breakdown is not None:
            self.show_category_breakdown = show_category_breakdown
        if show_change is not None:
            self.show_change = show_change

    @property
    def end_date(self):
        """Gets the end_date of this FinancialPictureRequest.  # noqa: E501


        :return: The end_date of this FinancialPictureRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this FinancialPictureRequest.


        :param end_date: The end_date of this FinancialPictureRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def client_id(self):
        """Gets the client_id of this FinancialPictureRequest.  # noqa: E501


        :return: The client_id of this FinancialPictureRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this FinancialPictureRequest.


        :param client_id: The client_id of this FinancialPictureRequest.  # noqa: E501
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def create_log(self):
        """Gets the create_log of this FinancialPictureRequest.  # noqa: E501


        :return: The create_log of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this FinancialPictureRequest.


        :param create_log: The create_log of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def currency_conversion(self):
        """Gets the currency_conversion of this FinancialPictureRequest.  # noqa: E501


        :return: The currency_conversion of this FinancialPictureRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_conversion

    @currency_conversion.setter
    def currency_conversion(self, currency_conversion):
        """Sets the currency_conversion of this FinancialPictureRequest.


        :param currency_conversion: The currency_conversion of this FinancialPictureRequest.  # noqa: E501
        :type: str
        """

        self._currency_conversion = currency_conversion

    @property
    def show_history(self):
        """Gets the show_history of this FinancialPictureRequest.  # noqa: E501


        :return: The show_history of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_history

    @show_history.setter
    def show_history(self, show_history):
        """Sets the show_history of this FinancialPictureRequest.


        :param show_history: The show_history of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._show_history = show_history

    @property
    def start_date(self):
        """Gets the start_date of this FinancialPictureRequest.  # noqa: E501


        :return: The start_date of this FinancialPictureRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this FinancialPictureRequest.


        :param start_date: The start_date of this FinancialPictureRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def currency_code(self):
        """Gets the currency_code of this FinancialPictureRequest.  # noqa: E501


        :return: The currency_code of this FinancialPictureRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this FinancialPictureRequest.


        :param currency_code: The currency_code of this FinancialPictureRequest.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def show_category_breakdown(self):
        """Gets the show_category_breakdown of this FinancialPictureRequest.  # noqa: E501


        :return: The show_category_breakdown of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_category_breakdown

    @show_category_breakdown.setter
    def show_category_breakdown(self, show_category_breakdown):
        """Sets the show_category_breakdown of this FinancialPictureRequest.


        :param show_category_breakdown: The show_category_breakdown of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._show_category_breakdown = show_category_breakdown

    @property
    def show_change(self):
        """Gets the show_change of this FinancialPictureRequest.  # noqa: E501


        :return: The show_change of this FinancialPictureRequest.  # noqa: E501
        :rtype: bool
        """
        return self._show_change

    @show_change.setter
    def show_change(self, show_change):
        """Sets the show_change of this FinancialPictureRequest.


        :param show_change: The show_change of this FinancialPictureRequest.  # noqa: E501
        :type: bool
        """

        self._show_change = show_change

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FinancialPictureRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FinancialPictureRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
