# coding: utf-8

"""
    Hydrogen Proton API

    Financial engineering module of Hydrogen Atom  # noqa: E501

    OpenAPI spec version: 1.8.0
    Contact: info@hydrogenplatform.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PortfolioOptimizationScoreRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'portfolio_tickers': 'list[str]',
        'end_date': 'date',
        'portfolio_id': 'str',
        'market_data_source': 'str',
        'model_id': 'str',
        'create_log': 'bool',
        'opt_config': 'OptConfig1',
        'allocation_id': 'str',
        'tgt_type': 'str',
        'use_proxy_data': 'bool',
        'start_date': 'date',
        'account_id': 'str',
        'aggregation_account_id': 'str',
        'portfolio_weights': 'list[float]'
    }

    attribute_map = {
        'portfolio_tickers': 'portfolio_tickers',
        'end_date': 'end_date',
        'portfolio_id': 'portfolio_id',
        'market_data_source': 'market_data_source',
        'model_id': 'model_id',
        'create_log': 'create_log',
        'opt_config': 'opt_config',
        'allocation_id': 'allocation_id',
        'tgt_type': 'tgt_type',
        'use_proxy_data': 'use_proxy_data',
        'start_date': 'start_date',
        'account_id': 'account_id',
        'aggregation_account_id': 'aggregation_account_id',
        'portfolio_weights': 'portfolio_weights'
    }

    def __init__(self, portfolio_tickers=None, end_date=None, portfolio_id=None, market_data_source='nucleus', model_id=None, create_log=False, opt_config=None, allocation_id=None, tgt_type='return', use_proxy_data=False, start_date=None, account_id=None, aggregation_account_id=None, portfolio_weights=None):  # noqa: E501
        """PortfolioOptimizationScoreRequest - a model defined in Swagger"""  # noqa: E501

        self._portfolio_tickers = None
        self._end_date = None
        self._portfolio_id = None
        self._market_data_source = None
        self._model_id = None
        self._create_log = None
        self._opt_config = None
        self._allocation_id = None
        self._tgt_type = None
        self._use_proxy_data = None
        self._start_date = None
        self._account_id = None
        self._aggregation_account_id = None
        self._portfolio_weights = None
        self.discriminator = None

        if portfolio_tickers is not None:
            self.portfolio_tickers = portfolio_tickers
        if end_date is not None:
            self.end_date = end_date
        if portfolio_id is not None:
            self.portfolio_id = portfolio_id
        if market_data_source is not None:
            self.market_data_source = market_data_source
        if model_id is not None:
            self.model_id = model_id
        if create_log is not None:
            self.create_log = create_log
        if opt_config is not None:
            self.opt_config = opt_config
        if allocation_id is not None:
            self.allocation_id = allocation_id
        if tgt_type is not None:
            self.tgt_type = tgt_type
        if use_proxy_data is not None:
            self.use_proxy_data = use_proxy_data
        if start_date is not None:
            self.start_date = start_date
        if account_id is not None:
            self.account_id = account_id
        if aggregation_account_id is not None:
            self.aggregation_account_id = aggregation_account_id
        if portfolio_weights is not None:
            self.portfolio_weights = portfolio_weights

    @property
    def portfolio_tickers(self):
        """Gets the portfolio_tickers of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The portfolio_tickers of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._portfolio_tickers

    @portfolio_tickers.setter
    def portfolio_tickers(self, portfolio_tickers):
        """Sets the portfolio_tickers of this PortfolioOptimizationScoreRequest.


        :param portfolio_tickers: The portfolio_tickers of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: list[str]
        """

        self._portfolio_tickers = portfolio_tickers

    @property
    def end_date(self):
        """Gets the end_date of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The end_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this PortfolioOptimizationScoreRequest.


        :param end_date: The end_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def portfolio_id(self):
        """Gets the portfolio_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The portfolio_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, portfolio_id):
        """Sets the portfolio_id of this PortfolioOptimizationScoreRequest.


        :param portfolio_id: The portfolio_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._portfolio_id = portfolio_id

    @property
    def market_data_source(self):
        """Gets the market_data_source of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The market_data_source of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._market_data_source

    @market_data_source.setter
    def market_data_source(self, market_data_source):
        """Sets the market_data_source of this PortfolioOptimizationScoreRequest.


        :param market_data_source: The market_data_source of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["nucleus", "integration"]  # noqa: E501
        if market_data_source not in allowed_values:
            raise ValueError(
                "Invalid value for `market_data_source` ({0}), must be one of {1}"  # noqa: E501
                .format(market_data_source, allowed_values)
            )

        self._market_data_source = market_data_source

    @property
    def model_id(self):
        """Gets the model_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The model_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this PortfolioOptimizationScoreRequest.


        :param model_id: The model_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def create_log(self):
        """Gets the create_log of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The create_log of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_log

    @create_log.setter
    def create_log(self, create_log):
        """Sets the create_log of this PortfolioOptimizationScoreRequest.


        :param create_log: The create_log of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: bool
        """

        self._create_log = create_log

    @property
    def opt_config(self):
        """Gets the opt_config of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The opt_config of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: OptConfig1
        """
        return self._opt_config

    @opt_config.setter
    def opt_config(self, opt_config):
        """Sets the opt_config of this PortfolioOptimizationScoreRequest.


        :param opt_config: The opt_config of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: OptConfig1
        """

        self._opt_config = opt_config

    @property
    def allocation_id(self):
        """Gets the allocation_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The allocation_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._allocation_id

    @allocation_id.setter
    def allocation_id(self, allocation_id):
        """Sets the allocation_id of this PortfolioOptimizationScoreRequest.


        :param allocation_id: The allocation_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._allocation_id = allocation_id

    @property
    def tgt_type(self):
        """Gets the tgt_type of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The tgt_type of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._tgt_type

    @tgt_type.setter
    def tgt_type(self, tgt_type):
        """Sets the tgt_type of this PortfolioOptimizationScoreRequest.


        :param tgt_type: The tgt_type of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["risk", "return"]  # noqa: E501
        if tgt_type not in allowed_values:
            raise ValueError(
                "Invalid value for `tgt_type` ({0}), must be one of {1}"  # noqa: E501
                .format(tgt_type, allowed_values)
            )

        self._tgt_type = tgt_type

    @property
    def use_proxy_data(self):
        """Gets the use_proxy_data of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The use_proxy_data of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_proxy_data

    @use_proxy_data.setter
    def use_proxy_data(self, use_proxy_data):
        """Sets the use_proxy_data of this PortfolioOptimizationScoreRequest.


        :param use_proxy_data: The use_proxy_data of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: bool
        """

        self._use_proxy_data = use_proxy_data

    @property
    def start_date(self):
        """Gets the start_date of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The start_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this PortfolioOptimizationScoreRequest.


        :param start_date: The start_date of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def account_id(self):
        """Gets the account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PortfolioOptimizationScoreRequest.


        :param account_id: The account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def aggregation_account_id(self):
        """Gets the aggregation_account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The aggregation_account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_account_id

    @aggregation_account_id.setter
    def aggregation_account_id(self, aggregation_account_id):
        """Sets the aggregation_account_id of this PortfolioOptimizationScoreRequest.


        :param aggregation_account_id: The aggregation_account_id of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: str
        """

        self._aggregation_account_id = aggregation_account_id

    @property
    def portfolio_weights(self):
        """Gets the portfolio_weights of this PortfolioOptimizationScoreRequest.  # noqa: E501


        :return: The portfolio_weights of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._portfolio_weights

    @portfolio_weights.setter
    def portfolio_weights(self, portfolio_weights):
        """Sets the portfolio_weights of this PortfolioOptimizationScoreRequest.


        :param portfolio_weights: The portfolio_weights of this PortfolioOptimizationScoreRequest.  # noqa: E501
        :type: list[float]
        """

        self._portfolio_weights = portfolio_weights

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PortfolioOptimizationScoreRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortfolioOptimizationScoreRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
